@@ -267,7 +267,20 @@ class Audiences(object):
 
     def run(self,
             data):
-        return [query.au_id for query in self.queries if query.run(data)]
+        parsed_data = self.parse_profile_data(data=data)
+        return [query.au_id for query in self.queries if query.run(parsed_data)]
+
+    def parse_profile_data(cls,
+                           data):
+        parsed = {}
+
+        for field_name, specs in cls.allowed_audience_fields.items():
+            if specs['type'] in cls.allowed_field_types:
+                value = (data.get(specs['propType']) or {}).get(field_name)
+                parsed[field_name] = value
+
+        return parsed
+
 
     @classmethod
     def parse_query(cls, query):
